@@ -23,7 +23,7 @@
 #' @export
 plot.Cosinor<-function(x,...){
 ## Checks
-  if (class(x)!="Cosinor"){stop("Object must be of class 'Cosinor'")} 
+  if (is(x, "Cosinor") ==FALSE){stop("Object must be of class 'Cosinor'")} 
   op <- par(no.readonly = TRUE) # the whole list of settable par's.
   on.exit(par(op)) # restore graphic settings
   f<-as.formula(x$call$formula)
