@@ -26,7 +26,7 @@
 #' @export 
 plot.monthglm<-function(x, alpha=0.05, ylim=NULL, ...){
   ## Checks
-  if (class(x)!="monthglm"){stop("Object must be of class 'monthglm'")} 
+  if (is(x,"monthglm")==FALSE){stop("Object must be of class 'monthglm'")} 
   op <- par(no.readonly = TRUE) # the whole list of settable par's.
   ## y-axis limits
   if(is.null(ylim)==FALSE){this.y.lim=ylim}
@@ -68,7 +68,7 @@ plot.monthglm<-function(x, alpha=0.05, ylim=NULL, ...){
   month.lab<-vector(mode='character',length=nrow(toplot))
   for (i in 1:nrow(toplot)){
     lines(c(order[i],order[i]),c(toplot$lower[i],toplot$upper[i]))
-    months.num<-as.numeric(nochars(row.names(toplot)[i]))
+    months.num<-as.numeric(stringr::str_remove_all(row.names(toplot)[i], pattern='[^0-9]')) # replaced `nochars`
     month.lab[i]<-month.abb[months.num]
   }
   month.lab<-substr(month.abb,1,1)
